Struct ProgrammerConnectedClockModeSelected

pub struct ProgrammerConnectedClockModeSelected { /* private fields */ }
A programmer connected to a device, with a clock mode selected

Implementations

Source

impl ProgrammerConnectedClockModeSelected

pub fn multiplication_ratios(&mut self) -> Result<Vec<Vec<MultiplicationRatio>>>

Retrieve a list of multiplication ratios supported by each clock

pub fn operating_frequencies(&mut self) -> Result<Vec<RangeInclusive<u16>>>

Retrive the operating frequency range of each clock

pub fn set_new_bit_rate( self, bit_rate: u16, input_frequency: u16, multiplication_ratios: Vec<MultiplicationRatio>, ) -> Result<ProgrammerConnectedNewBitRateSelected>

Sets a new bit rate for the device connection